Skip site navigation (1)Skip section navigation (2)
Date:      Tue, 15 Oct 2013 12:28:24 +0000 (UTC)
From:      Aleksandr Rybalko <ray@FreeBSD.org>
To:        src-committers@freebsd.org, svn-src-user@freebsd.org
Subject:   svn commit: r256527 - in user/ed/newcons/sys/dev/vt: . hw/intel hw/ofwfb hw/vga hw/xboxfb
Message-ID:  <201310151228.r9FCSO8o085202@svn.freebsd.org>

next in thread | raw e-mail | index | archive | help
Author: ray
Date: Tue Oct 15 12:28:24 2013
New Revision: 256527
URL: http://svnweb.freebsd.org/changeset/base/256527

Log:
  o Rename bitblt method to bitbltchr, since it used to copy char with bg/fg colors
  from font table, but not bitmap copy.
  o Fix small mistake in comment.
  
  Sponsored by:	The FreeBSD Foundation

Modified:
  user/ed/newcons/sys/dev/vt/hw/intel/intel.c
  user/ed/newcons/sys/dev/vt/hw/ofwfb/ofwfb.c
  user/ed/newcons/sys/dev/vt/hw/vga/vga.c
  user/ed/newcons/sys/dev/vt/hw/xboxfb/xboxfb.c
  user/ed/newcons/sys/dev/vt/vt.h
  user/ed/newcons/sys/dev/vt/vt_core.c

Modified: user/ed/newcons/sys/dev/vt/hw/intel/intel.c
==============================================================================
--- user/ed/newcons/sys/dev/vt/hw/intel/intel.c	Tue Oct 15 12:02:05 2013	(r256526)
+++ user/ed/newcons/sys/dev/vt/hw/intel/intel.c	Tue Oct 15 12:28:24 2013	(r256527)
@@ -60,11 +60,11 @@ static device_method_t intel_methods[] =
 };
 
 static vd_init_t	intel_vtinit;
-static vd_bitblt_t	intel_vtbitblt;
+static vd_bitbltchr_t	intel_vtbitbltchr;
 
 static struct vt_driver intel_vtops = {
 	.vd_init	= intel_vtinit,
-	.vd_bitblt	= intel_vtbitblt,
+	.vd_bitbltchr	= intel_vtbitbltchr,
 	/* Prefer to use KMS, so GENERIC - 10 */
 	.vd_priority	= VD_PRIORITY_GENERIC - 10,
 };
@@ -150,7 +150,7 @@ intel_vtinit(struct vt_device *vd)
 }
 
 static void
-intel_vtbitblt(struct vt_device *vd, const uint8_t *src,
+intel_vtbitbltchr(struct vt_device *vd, const uint8_t *src,
     vt_axis_t top, vt_axis_t left, unsigned int width, unsigned int height,
     term_color_t fg, term_color_t bg)
 {

Modified: user/ed/newcons/sys/dev/vt/hw/ofwfb/ofwfb.c
==============================================================================
--- user/ed/newcons/sys/dev/vt/hw/ofwfb/ofwfb.c	Tue Oct 15 12:02:05 2013	(r256526)
+++ user/ed/newcons/sys/dev/vt/hw/ofwfb/ofwfb.c	Tue Oct 15 12:28:24 2013	(r256527)
@@ -59,12 +59,12 @@ struct ofwfb_softc {
 
 static vd_init_t	ofwfb_init;
 static vd_blank_t	ofwfb_blank;
-static vd_bitblt_t	ofwfb_bitblt;
+static vd_bitbltchr_t	ofwfb_bitbltchr;
 
 static const struct vt_driver vt_ofwfb_driver = {
 	.vd_init	= ofwfb_init,
 	.vd_blank	= ofwfb_blank,
-	.vd_bitblt	= ofwfb_bitblt,
+	.vd_bitbltchr	= ofwfb_bitbltchr,
 	.vd_priority	= VD_PRIORITY_GENERIC,
 };
 
@@ -116,7 +116,7 @@ ofwfb_blank(struct vt_device *vd, term_c
 }
 
 static void
-ofwfb_bitblt(struct vt_device *vd, const uint8_t *src,
+ofwfb_bitbltchr(struct vt_device *vd, const uint8_t *src,
     vt_axis_t top, vt_axis_t left, unsigned int width, unsigned int height,
     term_color_t fg, term_color_t bg)
 {

Modified: user/ed/newcons/sys/dev/vt/hw/vga/vga.c
==============================================================================
--- user/ed/newcons/sys/dev/vt/hw/vga/vga.c	Tue Oct 15 12:02:05 2013	(r256526)
+++ user/ed/newcons/sys/dev/vt/hw/vga/vga.c	Tue Oct 15 12:28:24 2013	(r256527)
@@ -73,13 +73,13 @@ struct vga_softc {
 
 static vd_init_t	vga_init;
 static vd_blank_t	vga_blank;
-static vd_bitblt_t	vga_bitblt;
+static vd_bitbltchr_t	vga_bitbltchr;
 static vd_putchar_t	vga_putchar;
 
 static const struct vt_driver vt_vga_driver = {
 	.vd_init	= vga_init,
 	.vd_blank	= vga_blank,
-	.vd_bitblt	= vga_bitblt,
+	.vd_bitbltchr	= vga_bitbltchr,
 	.vd_putchar	= vga_putchar,
 	.vd_priority	= VD_PRIORITY_GENERIC,
 };
@@ -169,7 +169,7 @@ vga_bitblt_draw(struct vt_device *vd, co
 }
 
 static void
-vga_bitblt(struct vt_device *vd, const uint8_t *src,
+vga_bitbltchr(struct vt_device *vd, const uint8_t *src,
     vt_axis_t top, vt_axis_t left, unsigned int width, unsigned int height,
     term_color_t fg, term_color_t bg)
 {

Modified: user/ed/newcons/sys/dev/vt/hw/xboxfb/xboxfb.c
==============================================================================
--- user/ed/newcons/sys/dev/vt/hw/xboxfb/xboxfb.c	Tue Oct 15 12:02:05 2013	(r256526)
+++ user/ed/newcons/sys/dev/vt/hw/xboxfb/xboxfb.c	Tue Oct 15 12:28:24 2013	(r256527)
@@ -61,12 +61,12 @@ struct xbox_softc {
 
 static vd_init_t	xbox_init;
 static vd_blank_t	xbox_blank;
-static vd_bitblt_t	xbox_bitblt;
+static vd_bitbltchr_t	xbox_bitbltchr;
 
 static const struct vt_driver vt_xbox_driver = {
 	.vd_init	= xbox_init,
 	.vd_blank	= xbox_blank,
-	.vd_bitblt	= xbox_bitblt,
+	.vd_bitbltchr	= xbox_bitbltchr,
 	.vd_priority	= VD_PRIORITY_GENERIC,
 };
 
@@ -106,7 +106,7 @@ xbox_blank(struct vt_device *vd, term_co
 }
 
 static void
-xbox_bitblt(struct vt_device *vd, const uint8_t *src,
+xbox_bitbltchr(struct vt_device *vd, const uint8_t *src,
     vt_axis_t top, vt_axis_t left, unsigned int width, unsigned int height,
     term_color_t fg, term_color_t bg)
 {

Modified: user/ed/newcons/sys/dev/vt/vt.h
==============================================================================
--- user/ed/newcons/sys/dev/vt/vt_core.c	Tue Oct 15 12:02:05 2013	(r256526)
+++ user/ed/newcons/sys/dev/vt/vt_core.c	Tue Oct 15 12:28:24 2013	(r256527)
@@ -585,7 +585,7 @@ vt_bitblt_char(struct vt_device *vd, str
 		left = col * vf->vf_width +
 		    (vd->vd_width % vf->vf_width) / 2;
 
-		vd->vd_driver->vd_bitblt(vd, src, top, left,
+		vd->vd_driver->vd_bitbltchr(vd, src, top, left,
 		    vf->vf_width, vf->vf_height, fg, bg);
 	} else {
 		vd->vd_driver->vd_putchar(vd, TCHAR_CHARACTER(c),
@@ -692,7 +692,7 @@ vtterm_splash(struct vt_device *vd)
 		switch (vt_logo_depth) {
 		case 1:
 			/* XXX: Unhardcode colors! */
-			vd->vd_driver->vd_bitblt(vd, vt_logo_image, top, left,
+			vd->vd_driver->vd_bitbltchr(vd, vt_logo_image, top, left,
 			    vt_logo_width, vt_logo_height, 0xf, 0x0);
 		}
 		vd->vd_flags |= VDF_SPLASH;
@@ -1395,7 +1395,7 @@ vt_allocate(struct vt_driver *drv, void 
 	}
 	vd = main_vd;
 
-	/* Stop vd_flash periodic task. */
+	/* Stop vt_flush periodic task. */
 	if (vd->vd_curwindow != NULL)
 		callout_drain(&vd->vd_timer);
 



Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?201310151228.r9FCSO8o085202>
--- user/ed/newcons/sys/dev/vt/vt.h	Tue Oct 15 12:02:05 2013	(r256526)
+++ user/ed/newcons/sys/dev/vt/vt.h	Tue Oct 15 12:28:24 2013	(r256527)
@@ -204,7 +204,7 @@ struct vt_window {
 /*
  * Per-device driver routines.
  *
  * vd_bitblt is used when the driver operates in graphics mode, while
  * vd_putchar is used when the driver operates in text mode
  * (VDF_TEXTMODE).
  */
@@ -212,7 +212,7 @@ struct vt_window {
 typedef int vd_init_t(struct vt_device *vd);
 typedef void vd_postswitch_t(struct vt_device *vd);
 typedef void vd_blank_t(struct vt_device *vd, term_color_t color);
-typedef void vd_bitblt_t(struct vt_device *vd, const uint8_t *src,
+typedef void vd_bitbltchr_t(struct vt_device *vd, const uint8_t *src,
     vt_axis_t top, vt_axis_t left, unsigned int width, unsigned int height,
     term_color_t fg, term_color_t bg);
 typedef void vd_putchar_t(struct vt_device *vd, term_char_t,
@@ -224,7 +224,7 @@ struct vt_driver {
 
 	/* Drawing. */
 	vd_blank_t	*vd_blank;
-	vd_bitblt_t	*vd_bitblt;
+	vd_bitbltchr_t	*vd_bitbltchr;
 
 	/* Text mode operation. */
 	vd_putchar_t	*vd_putchar;
@@ -204,7 +204,7 @@ struct vt_window {
  * Per-device driver routines.
  *
- * vd_bitblt is used when the driver operates in graphics mode, while
+ * vd_bitbltchr is used when the driver operates in graphics mode, while
  * vd_putchar is used when the driver operates in text mode
  * (VDF_TEXTMODE).

Modified: user/ed/newcons/sys/dev/vt/vt_core.c
==============================================================================